<?php

class ccc_select_run extends crud_callback_chunk_run
{

    public function get_callback_string()
    {
        return '$this->crud->callback(\'' . $this->field . '\', \'rtgc_select\', [1 => \'name_1\', 2 => \'name_2\']);';
    }

}

class ccc_select implements crud_callback_chunk
{

    public function get_name()
    {
        return 'Select';
    }

    public function get_options()
    {
        return FALSE;
    }

    public function get_schema()
    {
        return 'int(11)';
    }

    public function run()
    {
        return new ccc_select_run();
    }

}
