<?php

if (!defined('BASEPATH')) {
    exit('No direct script access allowed');
}

/**
 * Event for module MODULE
 *
 * @author CIEXT skeleton
 */
class NAME_event implements SplObserver
{

    public function update(SplSubject $subject)
    {
        $event_name = $subject->get_event_name();
        $event_data = $subject->get_event_data();
    }

}
