<?php

if (!defined('BASEPATH')) {
    exit('No direct script access allowed');
}

/**
 * Description of CLASSNAME
 *
 * @author CIEXT skeleton
 */
class CLASSNAME extends \Ciext\Model\AbstractTableModel
{

    protected $table = 'TABLE';
    protected $pkey = 'id_TABLE';

}
