<?php

class ccc_price_usd_run extends crud_callback_chunk_run
{

    public function get_callback_string()
    {
        return '$this->crud->callback(\'' . $this->field . '\', \'rtgc_price\', \'usd\');';
    }

}

class ccc_price_usd implements crud_callback_chunk
{

    public function get_name()
    {
        return 'Price USD';
    }

    public function get_options()
    {
        return FALSE;
    }

    public function get_schema()
    {
        return 'float(10,2)';
    }

    public function run()
    {
        return new ccc_price_usd_run();
    }

}
