<?php

class ccc_multifield_run extends crud_callback_chunk_run
{

    public function get_callback_string()
    {
        return '$this->crud->multifield(\'' . $this->field. '\');';
    }

}

class ccc_multifield implements crud_callback_chunk
{

    public function get_name()
    {
        return 'Multifield';
    }

    public function get_options()
    {
        return new crud_callback_chunk_options();
    }

    public function get_schema()
    {
        return 'text';
    }

    public function run()
    {
        return new ccc_multifield_run();
    }

}
